qcacmn: Extend support for 'setratemask' cmd

Currently the 'setratemask' command supports setting
the rate mask for upto MCS0-9 and NSS 4. Add 'lower32_2'
field in the ratemask_params struct to extend support
for the 'setratemask' command to set rate mask
for upto MCS0-11 and NSS 8.

Change-Id: I9c06ae238142dca37df9826ca34449dd34ee6782
CRs-fixed: 2251392
diff --git a/wmi/src/wmi_unified_tlv.c b/wmi/src/wmi_unified_tlv.c
index 19b6273..cecf75b 100644
--- a/wmi/src/wmi_unified_tlv.c
+++ b/wmi/src/wmi_unified_tlv.c
@@ -10837,8 +10837,11 @@
 	cmd->type = param->type;
 	cmd->mask_lower32 = param->lower32;
 	cmd->mask_higher32 = param->higher32;
-	WMI_LOGI("Setting vdev ratemask vdev id = 0x%X, type = 0x%X, mask_l32 = 0x%X mask_h32 = 0x%X\n",
-		 param->vdev_id, param->type, param->lower32, param->higher32);
+	cmd->mask_lower32_2 = param->lower32_2;
+	WMI_LOGI("Setting vdev ratemask vdev id = 0x%X, type = 0x%X"
+		"mask_l32 = 0x%X mask_h32 = 0x%X mask_l32_2 = 0x%X\n",
+		param->vdev_id, param->type, param->lower32,
+		param->higher32, param->lower32_2);
 
 	if (wmi_unified_cmd_send(wmi_handle, buf, len,
 				 WMI_VDEV_RATEMASK_CMDID)) {
diff --git a/wmi/inc/wmi_unified_param.h b/wmi/inc/wmi_unified_param.h
index e80ee1c..9380c87 100644
--- a/wmi/inc/wmi_unified_param.h
+++ b/wmi/inc/wmi_unified_param.h
@@ -3777,14 +3777,16 @@
  * struct config_ratemask_params - ratemask config parameters
  * @vdev_id: vdev id
  * @type: Type
  * @lower32: Lower 32 bits
  * @higher32: Hogher 32 bits
  */
 struct config_ratemask_params {
 	uint8_t vdev_id;
 	uint8_t type;
 	uint32_t lower32;
 	uint32_t higher32;
+	uint32_t lower32_2;
 };
 
 /**
@@ -3777,14 +3777,16 @@
  * @vdev_id: vdev id
  * @type: Type
- * @lower32: Lower 32 bits
- * @higher32: Hogher 32 bits
+ * @lower32: Lower 32 bits in the 1st 64-bit value
+ * @higher32: Higher 32 bits in the 1st 64-bit value
+ * @lower32_2: Lower 32 bits in the 2nd 64-bit value
  */
 struct config_ratemask_params {